@@ -8,10 +8,6 @@
 
 #include "akonadiconsole-version.h"
 #include "instanceselector.h"
-#include <kcoreaddons_version.h>
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-#include <Kdelibs4ConfigMigrator>
-#endif
 
 #include <KAboutData>
 #include <KCrash>
@@ -25,18 +21,8 @@
 
 int main(int argc, char **argv)
 {
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling, true);
-    QCoreApplication::setAttribute(Qt::AA_UseHighDpiPixmaps, true);
-#endif
     QApplication app(argc, argv);
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    Kdelibs4ConfigMigrator migrate(QStringLiteral("akonadiconsole"));
-    migrate.setConfigFiles(QStringList() << QStringLiteral("akonadiconsolerc"));
-    migrate.setUiFiles(QStringList() << QStringLiteral("akonadiconsoleui.rc"));
-    migrate.migrate();
-#endif
-    KLocalizedString::setApplicationDomain("akonadiconsole");
+    KLocalizedString::setApplicationDomain(QByteArrayLiteral("akonadiconsole"));
     KAboutData aboutData(QStringLiteral("akonadiconsole"),
                          i18n("Akonadi Console"),
                          QStringLiteral(KDEPIM_VERSION),
@@ -64,9 +50,9 @@ int main(int argc, char **argv)
 
     KDBusService service;
 
-    qRegisterMetaType<QVector<QByteArray>>();
-    qDBusRegisterMetaType<QVector<qint64>>();
-    qDBusRegisterMetaType<QVector<QByteArray>>();
+    qRegisterMetaType<QList<QByteArray>>();
+    qDBusRegisterMetaType<QList<qint64>>();
+    qDBusRegisterMetaType<QList<QByteArray>>();
 
     if (parser.isSet(remoteOption)) {
         const QString akonadiAddr = QStringLiteral("tcp:host=%1,port=31415").arg(parser.value(QStringLiteral("remote")));
